@@ -1478,7 +1478,8 @@ ditem_execute (const GnomeDesktopItem *item,
                char **envp,
 	       gboolean launch_only_one,
 	       gboolean use_current_dir,
-		 gboolean append_uris,
+	       gboolean append_uris,
+	       gboolean append_paths,
 	       GError **error)
 {
 	char **real_argv;
@@ -1532,6 +1533,16 @@ ditem_execute (const GnomeDesktopItem *item,
 			added_status = ADDED_ALL;
 		}
 
+		/* append_uris and append_paths are mutually exlusive */
+		if (launched == 0 && added_status == ADDED_NONE && append_paths) {
+			uris = stringify_files (args, FALSE, FALSE);
+			temp = g_strconcat (new_exec, " ", uris, NULL);
+			g_free (uris);
+			g_free (new_exec);
+			new_exec = temp;
+			added_status = ADDED_ALL;
+		}
+
 		if (launched > 0 && added_status == ADDED_NONE) {
 			g_free (new_exec);
 			break;
@@ -1649,7 +1660,7 @@ gnome_desktop_item_launch (const GnomeDesktopItem *item,
 }
 
 /**
- * gnome_desktop_item_launch_wth_env:
+ * gnome_desktop_item_launch_with_env:
  * @item: A desktop item
  * @file_list:  Files/URIs to launch this item with, can be %NULL
  * @flags: FIXME
@@ -1736,6 +1747,7 @@ gnome_desktop_item_launch_with_env (const GnomeDesktopItem       *item,
 			     (flags & GNOME_DESKTOP_ITEM_LAUNCH_ONLY_ONE),
 			     (flags & GNOME_DESKTOP_ITEM_LAUNCH_USE_CURRENT_DIR),
 			     (flags & GNOME_DESKTOP_ITEM_LAUNCH_APPEND_URIS),
+			     (flags & GNOME_DESKTOP_ITEM_LAUNCH_APPEND_PATHS),
 			     error);
 
 	return ret;
@@ -2680,15 +2692,6 @@ standard_is_boolean (const char * key)
 	return g_hash_table_lookup (bools, key) != NULL;
 }
 
-static gboolean G_GNUC_CONST
-standard_is_numeric (const char *key)
-{
-	if (strcmp (key, GNOME_DESKTOP_ITEM_VERSION) == 0)
-		return TRUE;
-	else
-		return FALSE;
-}
-
 static gboolean G_GNUC_CONST
 standard_is_strings (const char *key)
 {
@@ -2730,16 +2733,15 @@ cannonize (const char *key, const char *value)
 		} else {
 			return g_strdup ("false");
 		}
-	} else if (standard_is_numeric (key)) {
-		double num = 0.0;
-		sscanf (value, "%lf", &num);
-		return g_strdup_printf ("%g", num);
 	} else if (standard_is_strings (key)) {
 		int len = strlen (value);
 		if (len == 0 || value[len-1] != ';') {
 			return g_strconcat (value, ";", NULL);
 		}
 	}
+	/* XXX: Perhaps we should canonize numeric values as well, but this
+	 * has caused some subtle problems before so it needs to be done
+	 * carefully if at all */
 	return NULL;
 }
 
@@ -3511,9 +3513,14 @@ ditem_save (GnomeDesktopItem *item, const char *uri, GError **error)
 	GList *li;
 	GnomeVFSHandle *handle;
 	GnomeVFSResult result;
+
 	result = gnome_vfs_open (&handle, uri, GNOME_VFS_OPEN_WRITE);
-	if (result == GNOME_VFS_ERROR_NOT_FOUND)
+	if (result == GNOME_VFS_ERROR_NOT_FOUND) {
 		result = gnome_vfs_create (&handle, uri, GNOME_VFS_OPEN_WRITE, TRUE, GNOME_VFS_PERM_USER_ALL);
+	} else {
+		result = gnome_vfs_truncate_handle (handle, 0);
+	}
+
 	if (result != GNOME_VFS_OK) {
 		g_set_error (error,
 			     /* FIXME: better errors */
